@@ -88,7 +88,7 @@ class Channel(base.AMQPChannel):
         it's  an exception or what.
 
         """
-        if exc_type:
+        if exc_type and exc_val:
             self._set_state(self.CLOSED)
             raise
         if self.open:
@@ -247,7 +247,7 @@ class Channel(base.AMQPChannel):
         elif isinstance(value, specification.Basic.Return):
             self._on_basic_return(self._wait_for_content_frames(value))
 
-    def _consume(self, obj, no_ack, priority):
+    def _consume(self, obj, no_ack, priority=None):
         """Register a Queue object as a consumer, issuing Basic.Consume.
 
         :param rabbitpy.amqp_queue.Queue obj: The queue to consume
@@ -316,9 +316,13 @@ class Channel(base.AMQPChannel):
         """
         try:
             frame_value = self._read_queue.get(False)
-            self._read_queue.task_done()
         except queue.Empty:
             return None
+
+        try:
+            self._read_queue.task_done()
+        except ValueError:
+            pass
         return frame_value
 
     def _get_message(self):
@@ -431,7 +435,7 @@ class Channel(base.AMQPChannel):
         :rtype: bool
 
         """
-        return self._server_capabilities.get(b'basic_nack', False)
+        return self._server_capabilities.get(b'basic.nack', False)
 
     @property
     def _supports_consumer_cancel_notify(self):
