@@ -5,8 +5,6 @@ Common rabbitpy events
 import logging
 import threading
 
-from rabbitpy import DEBUG
-
 LOGGER = logging.getLogger(__name__)
 
 CHANNEL0_CLOSE = 0x01
@@ -72,13 +70,11 @@ class Events(object):
 
         """
         if event_id not in self._events:
-            if DEBUG:
-                LOGGER.debug('Event does not exist: %s', description(event_id))
+            LOGGER.debug('Event does not exist: %s', description(event_id))
             return None
 
         if not self.is_set(event_id):
-            if DEBUG:
-                LOGGER.debug('Event is not set: %s', description(event_id))
+            LOGGER.debug('Event is not set: %s', description(event_id))
             return False
 
         self._events[event_id].clear()
@@ -93,8 +89,7 @@ class Events(object):
 
         """
         if event_id not in self._events:
-            if DEBUG:
-                LOGGER.debug('Event does not exist: %s', description(event_id))
+            LOGGER.debug('Event does not exist: %s', description(event_id))
             return None
         return self._events[event_id].is_set()
 
@@ -107,13 +102,11 @@ class Events(object):
 
         """
         if event_id not in self._events:
-            if DEBUG:
-                LOGGER.debug('Event does not exist: %s', description(event_id))
+            LOGGER.debug('Event does not exist: %s', description(event_id))
             return None
 
         if self.is_set(event_id):
-            if DEBUG:
-                LOGGER.debug('Event is already set: %s', description(event_id))
+            LOGGER.debug('Event is already set: %s', description(event_id))
             return False
 
         self._events[event_id].set()
@@ -130,10 +123,8 @@ class Events(object):
 
         """
         if event_id not in self._events:
-            if DEBUG:
-                LOGGER.debug('Event does not exist: %s', description(event_id))
+            LOGGER.debug('Event does not exist: %s', description(event_id))
             return None
-        if DEBUG:
-            LOGGER.debug('Waiting for %i seconds on event: %s',
-                         timeout, description(event_id))
+        LOGGER.debug('Waiting for %i seconds on event: %s',
+                     timeout, description(event_id))
         return self._events[event_id].wait(timeout)
